#!/bin/sh

###############################################################################
#  A Sort-Of Generalized PWscf SCF Script for AF Transition Metal Monoxides   #
#                          P. M. Grant                                        #
#                        February, 2008                                       #
###############################################################################

###############################################################################
#    Element and Structure-Specific Constants & Data (Meant To Be Edited)     #
#                              (!con cuidado!)                                #
#           Be especially careful to link to the rignt PP folder              #
#       THIS SCRIPT IS ONLY FOR af-Ordered TENORITE COPPER OXIDE!             #
###############################################################################

TM='Cu';	A='O'
TM_m='63.456';	A_m='15.9994'
a_Ang='0'	
#mp_size='2'
mp_size='4'

# PseudoPots List

# Copper
TM_pseudopot='Cu.pz-3d9_4s2-rrkjus.UPF';	
#TM_pseudopot='029-Cu-gpw-n-campos.uspp.UPF';	
#TM_pseudopot='CuLDA.RRKJ3.PAW'		
#TM_pseudopot='Cu.pz-d-rrkjus.UPF';
#TM_pseudopot='Cu.pz-n-van_ak.UPF';
#TM_pseudopot='Cu.blyp-n-van_ak.UPF';
#TM_pseudopot='Cu.pw91-n-van_ak.UPF';
# A
# Oxygen
#A_pseudopot='008-O-ca--vgrp.uspp.UPF'
#A_pseudopot='OLDA.RRKJ3.PAW'
#A_pseudopot='O.pz-rrkjus.UPF'
#A_pseudopot='O.LDA.US.RRKJ3.UPF'
#A_pseudopot='O.vdb.UPF'
A_pseudopot='O.pz-van_ak.UPF'
#A_pseudopot='O.pw91-van_ak.UPF'

# Magnetism Related Parameters
sm_A='0.0'
sm_TM='0.5'
#H_U='1.d-7'
H_U='5.0'
#H_U='7.5'
#H_U='3.0'
#H_U='4.3'
#H_U='7.1'
#U_p_t='atomic'
#U_p_t='file'
U_p_t='norm-atomic'
#s_ns_122=	s_ns_222=	s_ns_322=1	s_ns_422=	s_ns_522=
#s_ns_113=	s_ns_213=	s_ns_313=1	s_ns_413=	s_ns_513=
#s_ns_122=	s_ns_222=1	s_ns_322=1	s_ns_422=1	s_ns_522=1
#s_ns_113=	s_ns_213=1	s_ns_313=1	s_ns_413=1	s_ns_513=1

# Run Control Paramenters
electron_maxstep='100'

###############################################################################
# Housekeeping and Various Setup Stuff                                        #
###############################################################################
now=`date`
cd `echo $0 | sed 's/\(.*\)\/.*/\1/'`
home_dir=`pwd`
cd ..
home_dir_up1=`pwd`
cd $home_dir
#pwscf_distro='espresso-3.2.3'
#pwscf_distro='espresso4.0cvs'
pwscf_distro='O-sesame'
pwscf_exec='/home/pmpgrant/'$pwscf_distro'/PW/pw.x'
home_pot=$home_dir_up1'/PSEUDOPOTS'
prefix=af-$TM$A
# Conversion Factors for Calculations
Ryd_eV=13.6057
Bohr_Ang=0.529
A1=$A
TM1=$TM'1'
TM2=$TM'2'

# cat to $prefix.scf.data file
printf "$0 \n" > $prefix.scf.data
cat >> $prefix.scf.data << EOF
  A PWscf LDA+U script to calculate the electronic properties of $prefix
  Starting at $now
*******************************************************************************
Element, Structure and Run Parameter Editable Options (!con cuidado!)
---------------------------------------------------------------------
  TM = $TM		A = $A
  TM_mass = $TM_m	A_mass = $A_m
  a_Ang = $a_Ang		MP_mesh = $mp_size
  TM_PP = $TM_pseudopot	A_PP = $A_pseudopot
  Starting Magnetizations:
  A = $sm_A		TM = $sm_TM
  Hubbard_U = $H_U
  U_Projection_Type = $U_p_t
  Starting_ns_eigenvalues:
	122	222	322	422	522
	$s_ns_122	$s_ns_222	$s_ns_322	$s_ns_422	$s_ns_522	
	113	213	313	413	513
	$s_ns_113	$s_ns_213	$s_ns_313	$s_ns_413	$s_ns_513
  Maximum Number of SCF Iterations = $electron_maxstep	

*******************************************************************************
Housekeeping
------------
  PWscf Distro = $pwscf_distro
  My Home      = $home_dir
  PP Home      = $home_pot
  PW Exec      = $pwscf_exec
EOF

###############################################################################
# Generate SCF Run Stuff                                                      #
###############################################################################
a_Bohr=`echo "scale = 5; $a_Ang/$Bohr_Ang" | bc`
cat > $prefix.scf.in << EOF
 &control
  title = '$prefix.scf',		calculation = 'scf',
  restart_mode = 'from_scratch',	prefix = '$prefix',
  pseudo_dir = '$home_pot',
  outdir = '$home_dir',
  tprnfor = .false.,			tstress = .false.,	
  verbosity = 'minimal',
 /
 &system
  ibrav = 0,			celldm(1)=$a_Bohr,
  nat = 16,			ntyp = 3,
  ecutwfc = 60.0		ecutrho = 240.0,
  smearing = 'gauss',		degauss = 0.01,		occupations = 'smearing',
  nspin = 2,			
  starting_magnetization(1) = $sm_A,
  starting_magnetization(2) = -$sm_TM,
  starting_magnetization(3) = $sm_TM,
  lda_plus_u =.true.,
  Hubbard_U(2) = $H_U,	Hubbard_U(3) = $H_U,
  U_projection_type = '$U_p_t',
  starting_ns_eigenvalue(1,2,2) = $s_ns_122,
  starting_ns_eigenvalue(2,2,2) = $s_ns_222,
  starting_ns_eigenvalue(3,2,2) = $s_ns_322,
  starting_ns_eigenvalue(4,2,2) = $s_ns_422,
  starting_ns_eigenvalue(5,2,2) = $s_ns_522,
  starting_ns_eigenvalue(1,1,3) = $s_ns_113,
  starting_ns_eigenvalue(2,1,3) = $s_ns_213,
  starting_ns_eigenvalue(3,1,3) = $s_ns_313,
  starting_ns_eigenvalue(4,1,3) = $s_ns_413,
  starting_ns_eigenvalue(5,1,3) = $s_ns_513,
 /
 &electrons
  electron_maxstep      = $electron_maxstep
  mixing_mode		= 'plain',
  mixing_fixed_ns	= 0,
  diagonalization	= 'david',
  conv_thr		= 1.0d-6,
  mixing_beta		= 0.3,
 /
CELL_PARAMETERS
   14.15895	0.00000		0.00000
    0.00000	6.46853	        0.00000
   -1.08584	0.00000	       11.93684
ATOMIC_SPECIES
    $A1      $A_m          $A_pseudopot
    $TM1     $TM_m         $TM_pseudopot
    $TM2     $TM_m         $TM_pseudopot
ATOMIC_POSITIONS {angstrom}
  $A1		0.721099	3.142314	2.368768
  $A1		0.433797	1.992218	5.527117
  $A1		2.737897	0.280686	0.789592
  $A1		2.450300	1.430814	3.947669
  $A1		4.467389	1.992183	2.368769
  $A1		4.180091	3.142314	5.527117
  $A1		6.483738	1.430814	0.790086
  $A1		6.196889	0.280686	3.947940
  $TM1  	0.864750	0.855750	0.789592
  $TM1  	0.577445	0.855750	3.947939
  $TM1  	2.594248	2.567250	2.368768
  $TM1  	2.306946	2.567250	5.527117
  $TM2  	4.611040	0.855750	0.789592
  $TM2  	4.323742	0.855750	3.947941
  $TM2  	6.340539	2.567250	2.368768
  $TM2  	6.053241	2.567250	5.527117
K_POINTS {automatic}
    $mp_size    $mp_size    $mp_size    0    0    0
EOF
 
###############################################################################
# Do SCF Run                                                                  #
###############################################################################
cat >> $prefix.scf.data << EOF
  Beginning $prefix SCF...
  Starting at `date`
*******************************************************************************
$prefix.scf.in follows...
----------------------------------
EOF

cat >> $prefix.scf.data < $prefix.scf.in
cat >> $prefix.scf.data << EOF

*******************************************************************************
  Running $prefix SCF...
EOF

$pwscf_exec < $prefix.scf.in | tee $prefix.scf.out
cat >> $prefix.scf.data << EOF
  Finished...at `date`
  Collecting key data
  `grep 'kinetic-energy cutoff     ' $prefix.scf.out`
  `grep 'charge density cutoff     ' $prefix.scf.out`
  `grep 'convergence threshold     ' $prefix.scf.out`
  `grep 'mixing beta               ' $prefix.scf.out`
  `grep 'number of electrons       ' $prefix.scf.out`
  `grep 'number of Kohn-Sham states' $prefix.scf.out`
  `grep 'number of iterations used ' $prefix.scf.out`
  `grep 'Exchange-correlation      ' $prefix.scf.out`

  # k-points = `grep 'number of k points=' $prefix.scf.out | cut -c 25-30`
  Fermi Energy = `grep 'Fermi' $prefix.scf.out | cut -c 28-36`
  Total Energy = `grep '!' $prefix.scf.out | cut -c 35-48`

  Total CPU Time = `grep 'CPU time' $prefix.scf.out | cut -c 20-30`
  Total Wall Time = `grep 'wall time' $prefix.scf.out | cut -c 40-53`

  Iteration Summary
  -----------------
`grep 'estimated scf accuracy  ' $prefix.scf.out`
`grep 'total magnetization     ' $prefix.scf.out`
`grep 'absolute magnetization  ' $prefix.scf.out`
`grep 'Tr' $prefix.scf.out`
`grep 'nsum =' $prefix.scf.out`

  d-orbital occupations
  ---------------------
`grep -n 'eigenvalues:' $prefix.scf.out`
EOF
exit
